@@ -25,7 +25,7 @@
 
 set -e
 
-while getopts ":b:c:g:i:l:n:q:s:v:x:z:" opt; do
+while getopts ":b:c:g:i:l:n:q:s:v:x:y:z:" opt; do
   case "${opt}" in
     b)
       BUILD_CATALOG_SOURCE_NAME=${OPTARG}
@@ -57,6 +57,9 @@ while getopts ":b:c:g:i:l:n:q:s:v:x:z:" opt; do
     x)
       SAVE_FAILED_TEST_NS=${OPTARG}
       ;;
+    y)
+      SMOKE_TEST_ONLY=${OPTARG}
+      ;;
     z)
       CUSTOM_INSTALL_TEST=${OPTARG}
       ;;
@@ -129,16 +132,20 @@ export CAMEL_K_TEST_IMAGE_VERSION=${CUSTOM_VERSION}
 export CAMEL_K_TEST_SAVE_FAILED_TEST_NAMESPACE=${SAVE_FAILED_TEST_NS}
 
 if [ -n "${GLOBAL_OPERATOR_NAMESPACE}" ]; then
-  echo "Info: Tests being run using global operator"
-  export CAMEL_K_FORCE_GLOBAL_TEST=true
   export CAMEL_K_GLOBAL_OPERATOR_NS="${GLOBAL_OPERATOR_NAMESPACE}"
+else
+  export CAMEL_K_GLOBAL_OPERATOR_NS="default"
 fi
 
+export CAMEL_K_E2E_FAST_SETUP="true"
+
 # Then run all integration tests rather than ending on first failure
 set -e
 exit_code=0
-if [ "${CUSTOM_INSTALL_TEST}" == "true" ]; then
-  DO_TEST_PREBUILD=false GOTESTFMT="-json 2>&1 | gotestfmt" make test-common-with-custom-install || exit_code=1
+if [ "${SMOKE_TEST_ONLY}" == "true" ]; then
+  DO_TEST_PREBUILD=false GOTESTFMT="-json 2>&1 | gotestfmt" make test-smoke || exit_code=1
+elif [ "${CUSTOM_INSTALL_TEST}" == "true" ]; then
+  DO_TEST_PREBUILD=false GOTESTFMT="-json 2>&1 | gotestfmt" make test-advanced || exit_code=1
 else
   DO_TEST_PREBUILD=false GOTESTFMT="-json 2>&1 | gotestfmt" make test-common || exit_code=1
 fi
