@@ -32,6 +32,7 @@ import (
 	"github.com/apache/camel-k/v2/pkg/util/test"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
@@ -52,10 +53,11 @@ func TestManualConfig(t *testing.T) {
 	})
 	env := createBasicTestEnvironment()
 
-	res, err := keda.Configure(env)
-	assert.NoError(t, err)
+	res, condition, err := keda.Configure(env)
+	require.NoError(t, err)
 	assert.True(t, res)
-	assert.NoError(t, keda.Apply(env))
+	assert.Nil(t, condition)
+	require.NoError(t, keda.Apply(env))
 	so := getScaledObject(env)
 	assert.NotNil(t, so)
 	assert.Len(t, so.Spec.Triggers, 1)
@@ -90,10 +92,11 @@ func TestConfigFromSecret(t *testing.T) {
 		},
 	})
 
-	res, err := keda.Configure(env)
-	assert.NoError(t, err)
+	res, condition, err := keda.Configure(env)
+	require.NoError(t, err)
 	assert.True(t, res)
-	assert.NoError(t, keda.Apply(env))
+	assert.Nil(t, condition)
+	require.NoError(t, keda.Apply(env))
 	so := getScaledObject(env)
 	assert.NotNil(t, so)
 	assert.Len(t, so.Spec.Triggers, 1)
@@ -177,10 +180,11 @@ func TestKameletAutoDetection(t *testing.T) {
 			},
 		})
 
-	res, err := keda.Configure(env)
-	assert.NoError(t, err)
+	res, condition, err := keda.Configure(env)
+	require.NoError(t, err)
 	assert.True(t, res)
-	assert.NoError(t, keda.Apply(env))
+	assert.Nil(t, condition)
+	require.NoError(t, keda.Apply(env))
 	so := getScaledObject(env)
 	assert.NotNil(t, so)
 	assert.Len(t, so.Spec.Triggers, 1)
@@ -278,22 +282,24 @@ func TestPipeAutoDetection(t *testing.T) {
 		})
 
 	it, err := pipe.CreateIntegrationFor(env.Ctx, env.Client, &klb)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.NotNil(t, it)
 	env.Integration = it
 
 	it.Status.Phase = camelv1.IntegrationPhaseInitialization
 	init := trait.NewInitTrait()
-	ok, err := init.Configure(env)
-	assert.NoError(t, err)
+	ok, condition, err := init.Configure(env)
+	require.NoError(t, err)
 	assert.True(t, ok)
-	assert.NoError(t, init.Apply(env))
+	assert.Nil(t, condition)
+	require.NoError(t, init.Apply(env))
 
 	it.Status.Phase = camelv1.IntegrationPhaseDeploying
-	res, err := keda.Configure(env)
-	assert.NoError(t, err)
+	res, condition, err := keda.Configure(env)
+	require.NoError(t, err)
 	assert.True(t, res)
-	assert.NoError(t, keda.Apply(env))
+	assert.Nil(t, condition)
+	require.NoError(t, keda.Apply(env))
 	so := getScaledObject(env)
 	assert.NotNil(t, so)
 	assert.Len(t, so.Spec.Triggers, 1)
@@ -339,14 +345,15 @@ func TestHackReplicas(t *testing.T) {
 		},
 	)
 
-	res, err := keda.Configure(env)
-	assert.NoError(t, err)
+	res, condition, err := keda.Configure(env)
+	require.NoError(t, err)
 	assert.True(t, res)
-	assert.NoError(t, keda.Apply(env))
+	assert.Nil(t, condition)
+	require.NoError(t, keda.Apply(env))
 	scalesClient, err := env.Client.ScalesClient()
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	sc, err := scalesClient.Scales("test").Get(env.Ctx, camelv1.SchemeGroupVersion.WithResource("integrations").GroupResource(), "my-it", metav1.GetOptions{})
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, int32(1), sc.Spec.Replicas)
 }
 
@@ -386,14 +393,15 @@ func TestHackKLBReplicas(t *testing.T) {
 		},
 	)
 
-	res, err := keda.Configure(env)
-	assert.NoError(t, err)
+	res, condition, err := keda.Configure(env)
+	require.NoError(t, err)
 	assert.True(t, res)
-	assert.NoError(t, keda.Apply(env))
+	assert.Nil(t, condition)
+	require.NoError(t, keda.Apply(env))
 	scalesClient, err := env.Client.ScalesClient()
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	sc, err := scalesClient.Scales("test").Get(env.Ctx, camelv1.SchemeGroupVersion.WithResource("pipes").GroupResource(), "my-klb", metav1.GetOptions{})
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, int32(1), sc.Spec.Replicas)
 }
 
