@@ -28,6 +28,7 @@ import (
 	"github.com/apache/camel-k/v2/pkg/util/camel"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestTracingTraitOnQuarkus(t *testing.T) {
@@ -36,12 +37,13 @@ func TestTracingTraitOnQuarkus(t *testing.T) {
 	tt, _ := tracing.(*tracingTrait)
 	tt.Enabled = pointer.Bool(true)
 	tt.Endpoint = "http://endpoint3"
-	ok, err := tracing.Configure(e)
-	assert.Nil(t, err)
+	ok, condition, err := tracing.Configure(e)
+	require.NoError(t, err)
 	assert.True(t, ok)
+	assert.Nil(t, condition)
 
 	err = tracing.Apply(e)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	assert.Empty(t, e.ApplicationProperties["quarkus.jaeger.enabled"])
 	assert.Equal(t, "http://endpoint3", e.ApplicationProperties["quarkus.jaeger.endpoint"])
@@ -54,7 +56,7 @@ func createEnvironment(t *testing.T, catalogGen func() (*camel.RuntimeCatalog, e
 	t.Helper()
 
 	catalog, err := catalogGen()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	e := trait.Environment{
 		CamelCatalog:          catalog,
