@@ -22,6 +22,7 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/v2/pkg/util/cancellable"
@@ -35,7 +36,7 @@ type errorTestSteps struct {
 
 func TestFailure(t *testing.T) {
 	c, err := test.NewFakeClient()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	b := New(c)
 
