@@ -43,7 +43,7 @@ func newKameletAddRepoCmd(rootCmdOptions *RootCmdOptions) (*cobra.Command, *kame
 		Use:     "add-repo github:owner/repo[/path_to_kamelets_folder][@version] ...",
 		Short:   "Add a Kamelet repository",
 		Long:    `Add a Kamelet repository.`,
-		PreRunE: decode(&options),
+		PreRunE: decode(&options, options.Flags),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			if err := options.validate(args); err != nil {
 				return err
@@ -52,7 +52,7 @@ func newKameletAddRepoCmd(rootCmdOptions *RootCmdOptions) (*cobra.Command, *kame
 		},
 	}
 
-	cmd.Flags().StringP("operator-id", "x", "", "Id of the Operator to update. If not set, the active primary Integration Platform is updated.")
+	cmd.Flags().StringP("operator-id", "x", "", "Id of the Operator to update. If not set, the default active Integration Platform is updated.")
 
 	return &cmd, &options
 }
@@ -93,7 +93,7 @@ func (o *kameletAddRepoCommandOptions) run(cmd *cobra.Command, args []string) er
 		if err := checkURI(uri, platform.Spec.Kamelet.Repositories); err != nil {
 			return err
 		}
-		platform.Spec.Kamelet.Repositories = append(platform.Spec.Kamelet.Repositories, v1.IntegrationPlatformKameletRepositorySpec{
+		platform.Spec.Kamelet.Repositories = append(platform.Spec.Kamelet.Repositories, v1.KameletRepositorySpec{
 			URI: uri,
 		})
 	}
@@ -118,9 +118,9 @@ func (o *kameletUpdateRepoCommandOptions) getIntegrationPlatform(cmd *cobra.Comm
 	return &platform, nil
 }
 
-// findIntegrationPlatform gives the primary integration platform that could be found in the provided namespace.
+// findIntegrationPlatform gives the integration platform that could be found in the provided namespace.
 func (o *kameletUpdateRepoCommandOptions) findIntegrationPlatform(cmd *cobra.Command, c client.Client) (*v1.IntegrationPlatform, error) {
-	platforms, err := platformutil.ListPrimaryPlatforms(o.Context, c, o.Namespace)
+	platforms, err := platformutil.ListPlatforms(o.Context, c, o.Namespace)
 	if err != nil {
 		return nil, err
 	}
@@ -130,11 +130,11 @@ func (o *kameletUpdateRepoCommandOptions) findIntegrationPlatform(cmd *cobra.Com
 			return &p, nil
 		}
 	}
-	fmt.Fprintf(cmd.ErrOrStderr(), "Warning: No active primary IntegrationPlatform could be found in namespace %q\n", o.Namespace)
+	fmt.Fprintf(cmd.ErrOrStderr(), "Warning: No active IntegrationPlatform could be found in namespace %q\n", o.Namespace)
 	return nil, nil
 }
 
-func checkURI(uri string, repositories []v1.IntegrationPlatformKameletRepositorySpec) error {
+func checkURI(uri string, repositories []v1.KameletRepositorySpec) error {
 	if !kameletRepositoryURIRegexp.MatchString(uri) {
 		return fmt.Errorf("malformed Kamelet repository uri %s, the expected format is github:owner/repo[/path_to_kamelets_folder][@version]", uri)
 	}
