@@ -42,7 +42,7 @@ func newCmdLog(rootCmdOptions *RootCmdOptions) (*cobra.Command, *logCmdOptions)
 		Long:    `Print the logs of an integration.`,
 		Aliases: []string{"logs"},
 		Args:    options.validate,
-		PreRunE: decode(&options),
+		PreRunE: decode(&options, options.Flags),
 		RunE:    options.run,
 	}
 
@@ -95,6 +95,7 @@ func (o *logCmdOptions) run(cmd *cobra.Command, args []string) error {
 	currLogMsg := ""
 	newLogMsg := ""
 
+	// nolint:staticcheck // wrong deprecation notice --> https://github.com/kubernetes/apimachinery/issues/153
 	err = wait.PollImmediate(pollInterval, pollTimeout, func() (bool, error) {
 		//
 		// Reduce repetition of messages by tracking the last message
