@@ -60,7 +60,7 @@ func initializeRunCmdOptions(t *testing.T) (*runCmdOptions, *cobra.Command, Root
 
 	options, rootCmd := kamelTestPreAddCommandInit()
 	runCmdOptions := addTestRunCmd(*options, rootCmd)
-	kamelTestPostAddCommandInit(t, rootCmd)
+	kamelTestPostAddCommandInit(t, rootCmd, options)
 
 	return runCmdOptions, rootCmd, *options
 }
@@ -75,7 +75,7 @@ func initializeRunCmdOptionsWithOutput(t *testing.T) (*runCmdOptions, *cobra.Com
 
 	options, rootCmd := kamelTestPreAddCommandInitWithClient(fakeClient)
 	runCmdOptions := addTestRunCmdWithOutput(*options, rootCmd)
-	kamelTestPostAddCommandInit(t, rootCmd)
+	kamelTestPostAddCommandInit(t, rootCmd, options)
 
 	return runCmdOptions, rootCmd, *options
 }
@@ -105,28 +105,28 @@ func addTestRunCmdWithOutput(options RootCmdOptions, rootCmd *cobra.Command) *ru
 func TestRunNoFlag(t *testing.T) {
 	runCmdOptions, rootCmd, _ := initializeRunCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdRun, integrationSource)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	// Check default expected values
-	assert.Equal(t, false, runCmdOptions.Wait)
-	assert.Equal(t, false, runCmdOptions.Logs)
-	assert.Equal(t, false, runCmdOptions.Sync)
-	assert.Equal(t, false, runCmdOptions.Dev)
-	assert.Equal(t, true, runCmdOptions.UseFlows)
-	assert.Equal(t, false, runCmdOptions.Compression)
-	assert.Equal(t, false, runCmdOptions.Save)
+	assert.False(t, runCmdOptions.Wait)
+	assert.False(t, runCmdOptions.Logs)
+	assert.False(t, runCmdOptions.Sync)
+	assert.False(t, runCmdOptions.Dev)
+	assert.True(t, runCmdOptions.UseFlows)
+	assert.False(t, runCmdOptions.Compression)
+	assert.False(t, runCmdOptions.Save)
 }
 
 func TestRunNonExistingFlag(t *testing.T) {
 	_, rootCmd, _ := initializeRunCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdRun, "--nonExistingFlag", integrationSource)
-	assert.NotNil(t, err)
+	require.Error(t, err)
 }
 
 func TestRunCompressionFlag(t *testing.T) {
 	runCmdOptions, rootCmd, _ := initializeRunCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdRun, "--compression", integrationSource)
-	assert.Nil(t, err)
-	assert.Equal(t, true, runCmdOptions.Compression)
+	require.NoError(t, err)
+	assert.True(t, runCmdOptions.Compression)
 }
 
 func TestRunDependencyFlag(t *testing.T) {
@@ -136,7 +136,7 @@ func TestRunDependencyFlag(t *testing.T) {
 		"--dependency", "dependency2",
 		"--dependency", "dependency3",
 		integrationSource)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Len(t, runCmdOptions.Dependencies, 3)
 	assert.Equal(t, "dependency1", runCmdOptions.Dependencies[0])
 	assert.Equal(t, "dependency2", runCmdOptions.Dependencies[1])
@@ -146,16 +146,16 @@ func TestRunDependencyFlag(t *testing.T) {
 func TestRunDevFlag(t *testing.T) {
 	runCmdOptions, rootCmd, _ := initializeRunCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdRun, "--dev", integrationSource)
-	assert.Nil(t, err)
-	assert.Equal(t, true, runCmdOptions.Dev)
+	require.NoError(t, err)
+	assert.True(t, runCmdOptions.Dev)
 }
 
 func TestRunDevModeOutputFlag(t *testing.T) {
 	runCmdOptions, rootCmd, _ := initializeRunCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdRun, "--dev", "-o", "yaml", integrationSource)
-	assert.Equal(t, true, runCmdOptions.Dev)
+	assert.True(t, runCmdOptions.Dev)
 	assert.Equal(t, "yaml", runCmdOptions.OutputFormat)
-	assert.NotNil(t, err)
+	require.Error(t, err)
 	assert.Equal(t, "cannot use --dev with -o/--output option",
 		err.Error())
 }
@@ -166,7 +166,7 @@ func TestRunEnvFlag(t *testing.T) {
 		"--env", "env1",
 		"--env", "env2",
 		integrationSource)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Len(t, runCmdOptions.EnvVars, 2)
 	assert.Equal(t, "env1", runCmdOptions.EnvVars[0])
 	assert.Equal(t, "env2", runCmdOptions.EnvVars[1])
@@ -175,7 +175,7 @@ func TestRunEnvFlag(t *testing.T) {
 func TestRunKitFlag(t *testing.T) {
 	runCmdOptions, rootCmd, _ := initializeRunCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdRun, "--kit", "myKit", integrationSource)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "myKit", runCmdOptions.IntegrationKit)
 }
 
@@ -186,7 +186,7 @@ func TestRunLabelFlag(t *testing.T) {
 		"--label", "label2=l2",
 		"--label", "label3=l3",
 		integrationSource)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Len(t, runCmdOptions.Labels, 3)
 	assert.Equal(t, "label1=l1", runCmdOptions.Labels[0])
 	assert.Equal(t, "label2=l2", runCmdOptions.Labels[1])
@@ -196,14 +196,14 @@ func TestRunLabelFlag(t *testing.T) {
 func TestRunLabelWrongFormatFlag(t *testing.T) {
 	_, rootCmd, _ := initializeRunCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdRun, "--label", "label1", integrationSource)
-	assert.NotNil(t, err)
+	require.Error(t, err)
 }
 
 func TestRunLogsFlag(t *testing.T) {
 	runCmdOptions, rootCmd, _ := initializeRunCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdRun, "--logs", integrationSource)
-	assert.Nil(t, err)
-	assert.Equal(t, true, runCmdOptions.Logs)
+	require.NoError(t, err)
+	assert.True(t, runCmdOptions.Logs)
 }
 
 func TestRunMavenRepositoryFlag(t *testing.T) {
@@ -213,7 +213,7 @@ func TestRunMavenRepositoryFlag(t *testing.T) {
 		"--maven-repository", "repo2",
 		"--maven-repository", "repo3",
 		integrationSource)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Len(t, runCmdOptions.Repositories, 3)
 	assert.Equal(t, "repo1", runCmdOptions.Repositories[0])
 	assert.Equal(t, "repo2", runCmdOptions.Repositories[1])
@@ -223,7 +223,7 @@ func TestRunMavenRepositoryFlag(t *testing.T) {
 func TestRunNameFlag(t *testing.T) {
 	runCmdOptions, rootCmd, _ := initializeRunCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdRun, "--name", "myIntegration", integrationSource)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "myIntegration", runCmdOptions.IntegrationName)
 }
 
@@ -232,7 +232,7 @@ func TestRunOpenApiFlag(t *testing.T) {
 	_, err := test.ExecuteCommand(rootCmd, cmdRun,
 		"--open-api", "configmap:oapi2",
 		integrationSource)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Len(t, runCmdOptions.OpenAPIs, 1)
 	assert.Equal(t, "configmap:oapi2", runCmdOptions.OpenAPIs[0])
 }
@@ -243,20 +243,20 @@ func TestRunOpenApiInvalidFlag(t *testing.T) {
 		"--open-api", "secret:oapi1",
 		"--open-api", "oapi2",
 		integrationSource)
-	assert.NotNil(t, err)
+	require.Error(t, err)
 }
 
 func TestRunOutputFlag(t *testing.T) {
 	runCmdOptions, rootCmd, _ := initializeRunCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdRun, "-o", "yaml", integrationSource)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "yaml", runCmdOptions.OutputFormat)
 }
 
 func TestRunProfileFlag(t *testing.T) {
 	runCmdOptions, rootCmd, _ := initializeRunCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdRun, "--profile", "myProfile", integrationSource)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "myProfile", runCmdOptions.Profile)
 }
 
@@ -267,7 +267,7 @@ func TestRunPropertyFlag(t *testing.T) {
 		"--property", "property2",
 		"--property", "property3",
 		integrationSource)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Len(t, runCmdOptions.Properties, 3)
 	assert.Equal(t, "property1", runCmdOptions.Properties[0])
 	assert.Equal(t, "property2", runCmdOptions.Properties[1])
@@ -290,7 +290,7 @@ func TestExtractProperties_SingleKeyValue(t *testing.T) {
 	runCmdOptions, _, _ := initializeRunCmdOptionsWithOutput(t)
 	for _, val := range correctValues {
 		prop, err := runCmdOptions.extractProperties(nil, val)
-		assert.Nil(t, err)
+		require.NoError(t, err)
 		value, ok := prop.Get("key")
 		assert.True(t, ok)
 		assert.Equal(t, "val", value)
@@ -304,15 +304,15 @@ func TestExtractProperties_FromFile(t *testing.T) {
 		t.Error(err)
 	}
 
-	assert.Nil(t, tmpFile1.Close())
-	assert.Nil(t, os.WriteFile(tmpFile1.Name(), []byte(`
+	require.NoError(t, tmpFile1.Close())
+	require.NoError(t, os.WriteFile(tmpFile1.Name(), []byte(`
 	key=value
 	#key2=value2
 	my.key=value
 	`), 0o400))
 	runCmdOptions, _, _ := initializeRunCmdOptionsWithOutput(t)
 	props, err := runCmdOptions.extractProperties(nil, "file:"+tmpFile1.Name())
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, 2, props.Len())
 	for _, prop := range props.Keys() {
 		value, ok := props.Get(prop)
@@ -328,8 +328,8 @@ func TestExtractPropertiesFromFileAndSingleValue(t *testing.T) {
 		t.Error(err)
 	}
 
-	assert.Nil(t, tmpFile1.Close())
-	assert.Nil(t, os.WriteFile(tmpFile1.Name(), []byte(`
+	require.NoError(t, tmpFile1.Close())
+	require.NoError(t, os.WriteFile(tmpFile1.Name(), []byte(`
 	key=value
 	#key2=value2
 	my.key=value
@@ -338,7 +338,7 @@ func TestExtractPropertiesFromFileAndSingleValue(t *testing.T) {
 	properties := []string{"key=override", "file:" + tmpFile1.Name(), "my.key = override"}
 	runCmdOptions, _, _ := initializeRunCmdOptionsWithOutput(t)
 	props, err := runCmdOptions.mergePropertiesWithPrecedence(nil, properties)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, 2, props.Len())
 	val, ok := props.Get("key")
 	assert.True(t, ok)
@@ -355,12 +355,12 @@ func TestAddPropertyFile(t *testing.T) {
 		t.Error(err)
 	}
 
-	assert.Nil(t, tmpFile.Close())
-	assert.Nil(t, os.WriteFile(tmpFile.Name(), []byte(TestPropertyFileContent), 0o400))
+	require.NoError(t, tmpFile.Close())
+	require.NoError(t, os.WriteFile(tmpFile.Name(), []byte(TestPropertyFileContent), 0o400))
 
 	runCmdOptions, _, _ := initializeRunCmdOptionsWithOutput(t)
 	properties, err := runCmdOptions.convertToTraitParameter(nil, "file:"+tmpFile.Name(), "trait.properties")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, 3, len(properties))
 	assert.Equal(t, `trait.properties=a = b`, properties[0])
 	assert.Equal(t, `trait.properties=f = g:h`, properties[1])
@@ -370,7 +370,7 @@ func TestAddPropertyFile(t *testing.T) {
 func TestRunProperty(t *testing.T) {
 	runCmdOptions, _, _ := initializeRunCmdOptionsWithOutput(t)
 	properties, err := runCmdOptions.convertToTraitParameter(nil, `key=value\nnewline`, "trait.properties")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, 1, len(properties))
 	assert.Equal(t, `trait.properties=key = value\nnewline`, properties[0])
 }
@@ -381,7 +381,7 @@ func TestRunResourceFlag(t *testing.T) {
 		"--resource", "res1",
 		"--resource", "res2",
 		integrationSource)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Len(t, runCmdOptions.Resources, 2)
 	assert.Equal(t, "res1", runCmdOptions.Resources[0])
 	assert.Equal(t, "res2", runCmdOptions.Resources[1])
@@ -390,14 +390,14 @@ func TestRunResourceFlag(t *testing.T) {
 func TestRunSaveFlag(t *testing.T) {
 	runCmdOptions, rootCmd, _ := initializeRunCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdRun, "--save", integrationSource)
-	assert.Nil(t, err)
-	assert.Equal(t, true, runCmdOptions.Save)
+	require.NoError(t, err)
+	assert.True(t, runCmdOptions.Save)
 }
 
 func TestRunSourceFlag(t *testing.T) {
 	runCmdOptions, rootCmd, _ := initializeRunCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdRun, "--source", "source1", integrationSource)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Len(t, runCmdOptions.Sources, 1)
 	assert.Equal(t, "source1", runCmdOptions.Sources[0])
 }
@@ -405,8 +405,8 @@ func TestRunSourceFlag(t *testing.T) {
 func TestRunSyncFlag(t *testing.T) {
 	runCmdOptions, rootCmd, _ := initializeRunCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdRun, "--sync", integrationSource)
-	assert.Nil(t, err)
-	assert.Equal(t, true, runCmdOptions.Sync)
+	require.NoError(t, err)
+	assert.True(t, runCmdOptions.Sync)
 }
 
 func TestRunExistingTraitFlag(t *testing.T) {
@@ -415,7 +415,7 @@ func TestRunExistingTraitFlag(t *testing.T) {
 		"--trait", "jvm.enabled",
 		"--trait", "logging.enabled",
 		integrationSource)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Len(t, runCmdOptions.Traits, 2)
 	assert.Equal(t, "jvm.enabled", runCmdOptions.Traits[0])
 	assert.Equal(t, "logging.enabled", runCmdOptions.Traits[1])
@@ -426,7 +426,7 @@ func TestRunMissingTraitFlag(t *testing.T) {
 	_, err := test.ExecuteCommand(rootCmd, cmdRun,
 		"--trait", "bogus.missing",
 		integrationSource)
-	assert.NotNil(t, err)
+	require.Error(t, err)
 	assert.Equal(t, "trait bogus does not exist in catalog", err.Error())
 	assert.Len(t, runCmdOptions.Traits, 1)
 	assert.Equal(t, "bogus.missing", runCmdOptions.Traits[0])
@@ -452,9 +452,9 @@ func TestConfigureTraits(t *testing.T) {
 	traits := v1.Traits{}
 	err = configureTraits(runCmdOptions.Traits, &traits, catalog)
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	traitMap, err := trait.ToTraitMap(traits)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Len(t, traitMap, 4)
 	assertTraitConfiguration(t, traits.Affinity, &traitv1.AffinityTrait{PodAffinity: pointer.Bool(false)})
 	assertTraitConfiguration(t, traits.Environment, &traitv1.EnvironmentTrait{ContainerMeta: pointer.Bool(false)})
@@ -472,8 +472,8 @@ func assertTraitConfiguration(t *testing.T, trait interface{}, expected interfac
 func TestRunUseFlowsFlag(t *testing.T) {
 	runCmdOptions, rootCmd, _ := initializeRunCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdRun, "--use-flows=false", integrationSource)
-	assert.Nil(t, err)
-	assert.Equal(t, false, runCmdOptions.UseFlows)
+	require.NoError(t, err)
+	assert.False(t, runCmdOptions.UseFlows)
 }
 
 func TestRunVolumeFlag(t *testing.T) {
@@ -482,7 +482,7 @@ func TestRunVolumeFlag(t *testing.T) {
 		"-v", "pvcname:/container1/path",
 		"-v", "pvcname:/container2/path",
 		integrationSource)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Len(t, runCmdOptions.Volumes, 2)
 	assert.Equal(t, "pvcname:/container1/path", runCmdOptions.Volumes[0])
 	assert.Equal(t, "pvcname:/container2/path", runCmdOptions.Volumes[1])
@@ -494,7 +494,7 @@ func TestRunVolumeFlagWrongPVCFormat(t *testing.T) {
 		"-v", "pvcname",
 		"-v", "pvcname/container2/path",
 		integrationSource)
-	assert.NotNil(t, err)
+	require.Error(t, err)
 }
 
 func TestRunBuildPropertyFlag(t *testing.T) {
@@ -503,7 +503,7 @@ func TestRunBuildPropertyFlag(t *testing.T) {
 		"--build-property", "build-prop1=val1",
 		"--build-property", "build-prop2=val2",
 		integrationSource)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Len(t, runCmdOptions.BuildProperties, 2)
 	assert.Equal(t, "build-prop1=val1", runCmdOptions.BuildProperties[0])
 	assert.Equal(t, "build-prop2=val2", runCmdOptions.BuildProperties[1])
@@ -511,18 +511,14 @@ func TestRunBuildPropertyFlag(t *testing.T) {
 
 func TestRunValidateArgs(t *testing.T) {
 	runCmdOptions, rootCmd, _ := initializeRunCmdOptions(t)
-	args := []string{}
-	err := runCmdOptions.validateArgs(rootCmd, args)
-	assert.NotNil(t, err)
-	assert.Equal(t, "run expects at least 1 argument, received 0", err.Error())
 
-	args = []string{"run_test.go"}
-	err = runCmdOptions.validateArgs(rootCmd, args)
-	assert.Nil(t, err)
+	args := []string{"run_test.go"}
+	err := runCmdOptions.validateArgs(rootCmd, args)
+	require.NoError(t, err)
 
 	args = []string{"missing_file"}
 	err = runCmdOptions.validateArgs(rootCmd, args)
-	assert.NotNil(t, err)
+	require.Error(t, err)
 	assert.Equal(t, "one of the provided sources is not reachable: missing file or unsupported scheme in missing_file", err.Error())
 }
 
@@ -544,7 +540,7 @@ volumes:
 
 	integrationSpec := v1.IntegrationSpec{}
 	err := resolvePodTemplate(context.TODO(), rootCmd, templateText, &integrationSpec)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.NotNil(t, integrationSpec.PodTemplate)
 	assert.Equal(t, 1, len(integrationSpec.PodTemplate.Spec.Containers))
 	// assert.Equal(t, 1,len(integrationSpec.PodTemplate.Spec.Containers[0].VolumeMounts))
@@ -557,7 +553,7 @@ func TestResolveJsonPodTemplate(t *testing.T) {
 
 	err := resolvePodTemplate(context.TODO(), rootCmd, minifiedYamlTemplate, &integrationSpec)
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.NotNil(t, integrationSpec.PodTemplate)
 	assert.Equal(t, 2, len(integrationSpec.PodTemplate.Spec.Containers))
 }
@@ -566,8 +562,8 @@ func TestFilterBuildPropertyFiles(t *testing.T) {
 	inputValues := []string{"file:/tmp/test", "key=val"}
 	outputValues := filterBuildPropertyFiles(inputValues)
 
-	assert.Equal(t, len(outputValues), 1)
-	assert.Equal(t, outputValues[0], "/tmp/test")
+	assert.Len(t, outputValues, 1)
+	assert.Equal(t, "/tmp/test", outputValues[0])
 }
 
 const TestSrcContent = `
@@ -590,14 +586,14 @@ func TestOutputYaml(t *testing.T) {
 	}
 
 	assert.Nil(t, tmpFile.Close())
-	assert.Nil(t, os.WriteFile(tmpFile.Name(), []byte(TestSrcContent), 0o400))
+	require.NoError(t, os.WriteFile(tmpFile.Name(), []byte(TestSrcContent), 0o400))
 	fileName := filepath.Base(tmpFile.Name())
 
 	runCmdOptions, runCmd, _ := initializeRunCmdOptionsWithOutput(t)
 	output, err := test.ExecuteCommand(runCmd, cmdRun, tmpFile.Name(), "-o", "yaml")
 	assert.Equal(t, "yaml", runCmdOptions.OutputFormat)
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, fmt.Sprintf(`apiVersion: camel.apache.org/v1
 kind: Integration
 metadata:
@@ -624,14 +620,14 @@ func TestTrait(t *testing.T) {
 	}
 
 	assert.Nil(t, tmpFile.Close())
-	assert.Nil(t, os.WriteFile(tmpFile.Name(), []byte(TestSrcContent), 0o400))
+	require.NoError(t, os.WriteFile(tmpFile.Name(), []byte(TestSrcContent), 0o400))
 	fileName := filepath.Base(tmpFile.Name())
 
 	runCmdOptions, runCmd, _ := initializeRunCmdOptionsWithOutput(t)
 	output, err := test.ExecuteCommand(runCmd, cmdRun, tmpFile.Name(), "-o", "yaml", "-t", "mount.configs=configmap:my-cm", "--connect", "my-service-binding")
 	assert.Equal(t, "yaml", runCmdOptions.OutputFormat)
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, fmt.Sprintf(`apiVersion: camel.apache.org/v1
 kind: Integration
 metadata:
@@ -664,13 +660,13 @@ func TestMissingTrait(t *testing.T) {
 	}
 
 	assert.Nil(t, tmpFile.Close())
-	assert.Nil(t, os.WriteFile(tmpFile.Name(), []byte(TestSrcContent), 0o400))
+	require.NoError(t, os.WriteFile(tmpFile.Name(), []byte(TestSrcContent), 0o400))
 
 	runCmdOptions, runCmd, _ := initializeRunCmdOptionsWithOutput(t)
 	output, err := test.ExecuteCommand(runCmd, cmdRun, tmpFile.Name(), "-o", "yaml", "-t", "bogus.fail=i-must-fail")
 	assert.Equal(t, "yaml", runCmdOptions.OutputFormat)
 	assert.Equal(t, "Error: trait bogus does not exist in catalog\n", output)
-	assert.NotNil(t, err)
+	require.Error(t, err)
 }
 
 func TestResolveYamlPodTemplateWithSupplementalGroups(t *testing.T) {
@@ -682,7 +678,7 @@ securityContext:
 `
 	integrationSpec := v1.IntegrationSpec{}
 	err := resolvePodTemplate(context.TODO(), rootCmd, templateText, &integrationSpec)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.NotNil(t, integrationSpec.PodTemplate)
 	assert.NotNil(t, integrationSpec.PodTemplate.Spec)
 	assert.NotNil(t, integrationSpec.PodTemplate.Spec.SecurityContext)
@@ -697,7 +693,7 @@ func TestResolveJsonPodTemplateWithSupplementalGroups(t *testing.T) {
 
 	integrationSpec := v1.IntegrationSpec{}
 	err := resolvePodTemplate(context.TODO(), rootCmd, minifiedYamlTemplate, &integrationSpec)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.NotNil(t, integrationSpec.PodTemplate)
 	assert.NotNil(t, integrationSpec.PodTemplate.Spec)
 	assert.NotNil(t, integrationSpec.PodTemplate.Spec.SecurityContext)
@@ -714,12 +710,12 @@ func TestIntegrationServiceAccountName(t *testing.T) {
 	}
 
 	assert.Nil(t, tmpFile.Close())
-	assert.Nil(t, os.WriteFile(tmpFile.Name(), []byte(TestSrcContent), 0o400))
+	require.NoError(t, os.WriteFile(tmpFile.Name(), []byte(TestSrcContent), 0o400))
 
 	_, runCmd, _ := initializeRunCmdOptionsWithOutput(t)
 	output, err := test.ExecuteCommand(runCmd, cmdRun, tmpFile.Name(), "-o", "yaml", "--service-account", "my-service-account")
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Contains(t, output, "serviceAccountName: my-service-account")
 }
 
@@ -731,7 +727,7 @@ func TestFileProperties(t *testing.T) {
 	}
 
 	assert.Nil(t, tmpFile1.Close())
-	assert.Nil(t, os.WriteFile(tmpFile1.Name(), []byte(`
+	require.NoError(t, os.WriteFile(tmpFile1.Name(), []byte(`
 	key=${value}
 	#key2=value2
 	my.key=value
@@ -743,13 +739,13 @@ func TestFileProperties(t *testing.T) {
 	}
 
 	assert.Nil(t, tmpFile.Close())
-	assert.Nil(t, os.WriteFile(tmpFile.Name(), []byte(TestSrcContent), 0o400))
+	require.NoError(t, os.WriteFile(tmpFile.Name(), []byte(TestSrcContent), 0o400))
 	_, runCmd, _ := initializeRunCmdOptionsWithOutput(t)
 	output, err := test.ExecuteCommand(runCmd, cmdRun, tmpFile.Name(),
 		"-p", "file:"+tmpFile1.Name(),
 		"-o", "yaml",
 	)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.NotContains(t, output, "#key2")
 	assert.Contains(t, output, "my.key = value")
 	assert.Contains(t, output, "key = ${value}")
@@ -763,7 +759,7 @@ func TestPropertyShouldNotExpand(t *testing.T) {
 	}
 
 	assert.Nil(t, tmpFile1.Close())
-	assert.Nil(t, os.WriteFile(tmpFile1.Name(), []byte(`
+	require.NoError(t, os.WriteFile(tmpFile1.Name(), []byte(`
 	key=${value}
 	`), 0o400))
 
@@ -773,7 +769,7 @@ func TestPropertyShouldNotExpand(t *testing.T) {
 	}
 
 	assert.Nil(t, tmpFile.Close())
-	assert.Nil(t, os.WriteFile(tmpFile.Name(), []byte(TestSrcContent), 0o400))
+	require.NoError(t, os.WriteFile(tmpFile.Name(), []byte(TestSrcContent), 0o400))
 	_, runCmd, _ := initializeRunCmdOptionsWithOutput(t)
 	output, err := test.ExecuteCommand(runCmd, cmdRun, tmpFile.Name(),
 		"-o", "yaml",
@@ -781,7 +777,7 @@ func TestPropertyShouldNotExpand(t *testing.T) {
 		"--build-property", "buildProp=${value}",
 		"-p", "file:"+tmpFile1.Name(),
 	)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Contains(t, output, "runtimeProp = ${value}")
 	assert.Contains(t, output, "buildProp = ${value}")
 	assert.Contains(t, output, "key = ${value}")
@@ -796,23 +792,136 @@ func TestRunOutput(t *testing.T) {
 	defer tmpFile1.Close()
 
 	assert.Nil(t, tmpFile1.Sync())
-	assert.Nil(t, os.WriteFile(tmpFile1.Name(), []byte(yamlIntegration), 0o400))
+	require.NoError(t, os.WriteFile(tmpFile1.Name(), []byte(yamlIntegration), 0o400))
 
 	_, rootCmd, _ := initializeRunCmdOptionsWithOutput(t)
 	output, err := test.ExecuteCommand(rootCmd, cmdRun, tmpFile1.Name())
 	_, fileName := filepath.Split(tmpFile1.Name())
 	integrationName := strings.TrimSuffix(fileName, filepath.Ext(fileName))
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, fmt.Sprintf("Integration \"%s\" created\n", integrationName), output)
 
 	output, err = test.ExecuteCommand(rootCmd, cmdRun, tmpFile1.Name())
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, fmt.Sprintf("Integration \"%s\" unchanged\n", integrationName), output)
 
-	assert.Nil(t, os.WriteFile(tmpFile1.Name(), []byte(strings.Replace(yamlIntegration, "Hello", "Hi", 1)), 0o400))
+	require.NoError(t, os.WriteFile(tmpFile1.Name(), []byte(strings.Replace(yamlIntegration, "Hello", "Hi", 1)), 0o400))
 	assert.Nil(t, tmpFile1.Sync())
 	output, err = test.ExecuteCommand(rootCmd, cmdRun, tmpFile1.Name())
-	assert.Nil(t, err)
+	require.NoError(t, err)
+	assert.Equal(t, fmt.Sprintf("Integration \"%s\" updated\n", integrationName), output)
+}
+
+func TestRunGlob(t *testing.T) {
+	dir, err := os.MkdirTemp("", "camel-k-TestRunGlob-*")
+	if err != nil {
+		t.Error(err)
+	}
+
+	pattern := "camel-k-*.yaml"
+
+	tmpFile1, err := os.CreateTemp(dir, pattern)
+	if err != nil {
+		t.Error(err)
+	}
+	defer tmpFile1.Close()
+	assert.Nil(t, tmpFile1.Sync())
+	require.NoError(t, os.WriteFile(tmpFile1.Name(), []byte(yamlIntegration), 0o400))
+
+	tmpFile2, err := os.CreateTemp(dir, pattern)
+	if err != nil {
+		t.Error(err)
+	}
+	defer tmpFile2.Close()
+	assert.Nil(t, tmpFile2.Sync())
+	require.NoError(t, os.WriteFile(tmpFile2.Name(), []byte(yamlIntegration), 0o400))
+
+	integrationName := "myname"
+
+	_, rootCmd, _ := initializeRunCmdOptionsWithOutput(t)
+
+	file := fmt.Sprintf("%s%c%s*", dir, os.PathSeparator, "camel-k-*") // = dir/camel-k-*
+
+	output, err := test.ExecuteCommand(rootCmd, cmdRun, "--name", integrationName, file)
+	require.NoError(t, err)
+	assert.Equal(t, fmt.Sprintf("Integration \"%s\" created\n", integrationName), output)
+}
+
+func TestRunGlobAllFiles(t *testing.T) {
+	dir, err := os.MkdirTemp("", "camel-k-TestRunGlobAllFiles-*")
+	if err != nil {
+		t.Error(err)
+	}
+
+	pattern := "camel-k-*.yaml"
+
+	tmpFile1, err := os.CreateTemp(dir, pattern)
+	if err != nil {
+		t.Error(err)
+	}
+	defer tmpFile1.Close()
+	assert.Nil(t, tmpFile1.Sync())
+	require.NoError(t, os.WriteFile(tmpFile1.Name(), []byte(yamlIntegration), 0o400))
+
+	tmpFile2, err := os.CreateTemp(dir, pattern)
+	if err != nil {
+		t.Error(err)
+	}
+	defer tmpFile2.Close()
+	assert.Nil(t, tmpFile2.Sync())
+	require.NoError(t, os.WriteFile(tmpFile2.Name(), []byte(yamlIntegration), 0o400))
+
+	integrationName := "myname"
+
+	_, rootCmd, _ := initializeRunCmdOptionsWithOutput(t)
+
+	file := fmt.Sprintf("%s%c*", dir, os.PathSeparator) // = dir/*
+
+	output, err := test.ExecuteCommand(rootCmd, cmdRun, "--name", integrationName, file)
+	require.NoError(t, err)
+	assert.Equal(t, fmt.Sprintf("Integration \"%s\" created\n", integrationName), output)
+}
+
+func TestRunGlobChange(t *testing.T) {
+	dir, err := os.MkdirTemp("", "camel-k-TestRunGlobChange-*")
+	if err != nil {
+		t.Error(err)
+	}
+
+	pattern := "camel-k-*.yaml"
+
+	tmpFile1, err := os.CreateTemp(dir, pattern)
+	if err != nil {
+		t.Error(err)
+	}
+	defer tmpFile1.Close()
+	assert.Nil(t, tmpFile1.Sync())
+	require.NoError(t, os.WriteFile(tmpFile1.Name(), []byte(yamlIntegration), 0o400))
+
+	integrationName := "myname"
+
+	_, rootCmd, _ := initializeRunCmdOptionsWithOutput(t)
+
+	file := fmt.Sprintf("%s%c%s", dir, os.PathSeparator, "camel-k-*")
+
+	output, err := test.ExecuteCommand(rootCmd, cmdRun, "--name", integrationName, file)
+	require.NoError(t, err)
+	assert.Equal(t, fmt.Sprintf("Integration \"%s\" created\n", integrationName), output)
+
+	output, err = test.ExecuteCommand(rootCmd, cmdRun, "--name", integrationName, file)
+	require.NoError(t, err)
+	assert.Equal(t, fmt.Sprintf("Integration \"%s\" unchanged\n", integrationName), output)
+
+	tmpFile2, err := os.CreateTemp(dir, pattern)
+	if err != nil {
+		t.Error(err)
+	}
+	defer tmpFile2.Close()
+	assert.Nil(t, tmpFile2.Sync())
+	require.NoError(t, os.WriteFile(tmpFile2.Name(), []byte(yamlIntegration), 0o400))
+
+	output, err = test.ExecuteCommand(rootCmd, cmdRun, "--name", integrationName, file)
+	require.NoError(t, err)
 	assert.Equal(t, fmt.Sprintf("Integration \"%s\" updated\n", integrationName), output)
 }
 
@@ -826,3 +935,27 @@ func TestRunOutputWithoutKubernetesCluster(t *testing.T) {
 	_, err = test.ExecuteCommand(rootCmd, cmdRun, "-o", "yaml", integrationSource)
 	require.NoError(t, err)
 }
+
+func TestSourceLessIntegration(t *testing.T) {
+	runCmdOptions, runCmd, _ := initializeRunCmdOptionsWithOutput(t)
+	output, err := test.ExecuteCommand(runCmd, cmdRun, "--image", "docker.io/my-org/my-app:1.0.0", "-o", "yaml", "-t", "mount.configs=configmap:my-cm")
+	assert.Equal(t, "yaml", runCmdOptions.OutputFormat)
+
+	require.NoError(t, err)
+	assert.Equal(t, `apiVersion: camel.apache.org/v1
+kind: Integration
+metadata:
+  annotations:
+    camel.apache.org/operator.id: camel-k
+  creationTimestamp: null
+  name: my-app-v1
+spec:
+  traits:
+    container:
+      image: docker.io/my-org/my-app:1.0.0
+    mount:
+      configs:
+      - configmap:my-cm
+status: {}
+`, output)
+}
