@@ -19,8 +19,6 @@ package integration
 
 import (
 	"context"
-	"fmt"
-	"reflect"
 
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/labels"
@@ -29,6 +27,7 @@ import (
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
 
+	"github.com/apache/camel-k/v2/pkg/client"
 	"github.com/apache/camel-k/v2/pkg/platform"
 	"github.com/apache/camel-k/v2/pkg/trait"
 	"github.com/apache/camel-k/v2/pkg/util"
@@ -36,7 +35,7 @@ import (
 	"github.com/apache/camel-k/v2/pkg/util/log"
 )
 
-func lookupKitsForIntegration(ctx context.Context, c ctrl.Reader, integration *v1.Integration, options ...ctrl.ListOption) ([]v1.IntegrationKit, error) {
+func lookupKitsForIntegration(ctx context.Context, c client.Client, integration *v1.Integration, options ...ctrl.ListOption) ([]v1.IntegrationKit, error) {
 	pl, err := platform.GetForResource(ctx, c, integration)
 	if err != nil && !k8serrors.IsNotFound(err) {
 		return nil, err
@@ -70,7 +69,7 @@ func lookupKitsForIntegration(ctx context.Context, c ctrl.Reader, integration *v
 	kits := make([]v1.IntegrationKit, 0)
 	for i := range list.Items {
 		kit := &list.Items[i]
-		match, err := integrationMatches(integration, kit)
+		match, err := integrationMatches(ctx, c, integration, kit)
 		if err != nil {
 			return nil, err
 		} else if !match || kit.Status.Phase == v1.IntegrationKitPhaseError {
@@ -84,18 +83,18 @@ func lookupKitsForIntegration(ctx context.Context, c ctrl.Reader, integration *v
 
 // sameOrMatch returns whether the v1.IntegrationKit is the one used by the v1.Integration or if it meets the
 // requirements of the v1.Integration.
-func sameOrMatch(kit *v1.IntegrationKit, integration *v1.Integration) (bool, error) {
+func sameOrMatch(ctx context.Context, c client.Client, kit *v1.IntegrationKit, integration *v1.Integration) (bool, error) {
 	if integration.Status.IntegrationKit != nil {
 		if integration.Status.IntegrationKit.Namespace == kit.Namespace && integration.Status.IntegrationKit.Name == kit.Name {
 			return true, nil
 		}
 	}
 
-	return integrationMatches(integration, kit)
+	return integrationMatches(ctx, c, integration, kit)
 }
 
 // integrationMatches returns whether the v1.IntegrationKit meets the requirements of the v1.Integration.
-func integrationMatches(integration *v1.Integration, kit *v1.IntegrationKit) (bool, error) {
+func integrationMatches(ctx context.Context, c client.Client, integration *v1.Integration, kit *v1.IntegrationKit) (bool, error) {
 	ilog := log.ForIntegration(integration)
 
 	ilog.Debug("Matching integration", "integration", integration.Name, "integration-kit", kit.Name, "namespace", integration.Namespace)
@@ -114,16 +113,24 @@ func integrationMatches(integration *v1.Integration, kit *v1.IntegrationKit) (bo
 	// A kit can be used only if it contains a subset of the traits and related configurations
 	// declared on integration.
 
-	itc, err := trait.NewTraitsOptionsForIntegration(integration)
+	pl, err := platform.GetForResource(ctx, c, integration)
+	if err != nil && !k8serrors.IsNotFound(err) {
+		return false, err
+	}
+	if _, err := platform.ApplyIntegrationProfile(ctx, c, pl, integration); err != nil {
+		return false, err
+	}
+
+	itc, err := trait.NewSpecTraitsOptionsForIntegrationAndPlatform(integration, pl)
 	if err != nil {
 		return false, err
 	}
-	ikc, err := trait.NewTraitsOptionsForIntegrationKit(kit)
+	ikc, err := trait.NewSpecTraitsOptionsForIntegrationKit(kit)
 	if err != nil {
 		return false, err
 	}
 
-	if match, err := hasMatchingTraits(itc, ikc); !match || err != nil {
+	if match, err := trait.HasMatchingTraits(itc, ikc); !match || err != nil {
 		ilog.Debug("Integration and integration-kit traits do not match", "integration", integration.Name, "integration-kit", kit.Name, "namespace", integration.Namespace)
 		return false, err
 	}
@@ -133,7 +140,7 @@ func integrationMatches(integration *v1.Integration, kit *v1.IntegrationKit) (bo
 	}
 	// If IntegrationKit has any source, we must verify that it corresponds with the one in the Integration.
 	// This is important in case of Native builds as we need to rebuild when language requires a source during build.
-	if (kit.Spec.Sources != nil && len(kit.Spec.Sources) > 0) && !hasMatchingSources(integration, kit) {
+	if (kit.Spec.Sources != nil && len(kit.Spec.Sources) > 0) && !hasMatchingSourcesForNative(integration, kit) {
 		ilog.Debug("Integration and integration-kit sources do not match", "integration", integration.Name, "integration-kit", kit.Name, "namespace", integration.Namespace)
 		return false, nil
 	}
@@ -162,105 +169,45 @@ func statusMatches(integration *v1.Integration, kit *v1.IntegrationKit, ilog *lo
 	return true
 }
 
-// kitMatches returns whether the two v1.IntegrationKit match.
-func kitMatches(kit1 *v1.IntegrationKit, kit2 *v1.IntegrationKit) (bool, error) {
-	version := kit1.Status.Version
+// kitMatches returns whether the kit matches with the existing target kit.
+func kitMatches(kit *v1.IntegrationKit, target *v1.IntegrationKit) (bool, error) {
+	version := kit.Status.Version
 	if version == "" {
 		// Defaults with the version that is going to be set during the kit initialization
 		version = defaults.Version
 	}
-	if version != kit2.Status.Version {
+	if version != target.Status.Version {
 		return false, nil
 	}
-	if len(kit1.Spec.Dependencies) != len(kit2.Spec.Dependencies) {
+	if len(kit.Spec.Dependencies) != len(target.Spec.Dependencies) {
 		return false, nil
 	}
 
-	c1, err := trait.NewTraitsOptionsForIntegrationKit(kit1)
+	// We cannot have yet the status set
+	c1, err := trait.NewSpecTraitsOptionsForIntegrationKit(kit)
 	if err != nil {
 		return false, err
 	}
-	c2, err := trait.NewTraitsOptionsForIntegrationKit(kit2)
+	c2, err := trait.NewSpecTraitsOptionsForIntegrationKit(target)
 	if err != nil {
 		return false, err
 	}
 
-	if match, err := hasMatchingTraits(c1, c2); !match || err != nil {
+	if match, err := trait.HasMatchingTraits(c1, c2); !match || err != nil {
 		return false, err
 	}
-	if !util.StringSliceContains(kit1.Spec.Dependencies, kit2.Spec.Dependencies) {
+	if !util.StringSliceContains(kit.Spec.Dependencies, target.Spec.Dependencies) {
 		return false, nil
 	}
 
 	return true, nil
 }
 
-func hasMatchingTraits(traitMap trait.Options, kitTraitMap trait.Options) (bool, error) {
-	catalog := trait.NewCatalog(nil)
-
-	for _, t := range catalog.AllTraits() {
-		if t == nil {
-			continue
-		}
-
-		id := string(t.ID())
-		it, ok1 := traitMap.Get(id)
-		kt, ok2 := kitTraitMap.Get(id)
-
-		if !ok1 && !ok2 {
-			continue
-		}
-
-		if t.InfluencesKit() && t.InfluencesBuild(it, kt) {
-			if ct, ok := t.(trait.ComparableTrait); ok {
-				// if it's match trait use its matches method to determine the match
-				if match, err := matchesComparableTrait(ct, it, kt); !match || err != nil {
-					return false, err
-				}
-			} else {
-				if !matchesTrait(it, kt) {
-					return false, nil
-				}
-			}
-		}
-	}
-
-	return true, nil
-}
-
-func matchesComparableTrait(ct trait.ComparableTrait, it map[string]interface{}, kt map[string]interface{}) (bool, error) {
-	t1 := reflect.New(reflect.TypeOf(ct).Elem()).Interface()
-	if err := trait.ToTrait(it, &t1); err != nil {
-		return false, err
-	}
-
-	t2 := reflect.New(reflect.TypeOf(ct).Elem()).Interface()
-	if err := trait.ToTrait(kt, &t2); err != nil {
-		return false, err
-	}
-
-	ct2, ok := t2.(trait.ComparableTrait)
-	if !ok {
-		return false, fmt.Errorf("type assertion failed: %v", t2)
-	}
-	tt1, ok := t1.(trait.Trait)
-	if !ok {
-		return false, fmt.Errorf("type assertion failed: %v", t1)
-	}
-
-	return ct2.Matches(tt1), nil
-}
-
-func matchesTrait(it map[string]interface{}, kt map[string]interface{}) bool {
-	// perform exact match on the two trait maps
-	return reflect.DeepEqual(it, kt)
-}
-
-func hasMatchingSources(it *v1.Integration, kit *v1.IntegrationKit) bool {
-	if len(it.Sources()) != len(kit.Spec.Sources) {
+func hasMatchingSourcesForNative(it *v1.Integration, kit *v1.IntegrationKit) bool {
+	if len(it.UserDefinedSources()) != len(kit.Spec.Sources) {
 		return false
 	}
-	for _, itSource := range it.Sources() {
+	for _, itSource := range it.UserDefinedSources() {
 		found := false
 		for _, ikSource := range kit.Spec.Sources {
 			if itSource.Content == ikSource.Content {
