@@ -22,20 +22,29 @@ import (
 	"testing"
 
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/utils/pointer"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 
 	"github.com/apache/camel-k/v2/pkg/trait"
-	"github.com/apache/camel-k/v2/pkg/util/log"
 	"github.com/apache/camel-k/v2/pkg/util/test"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestLookupKitForIntegration_DiscardKitsInError(t *testing.T) {
 	c, err := test.NewFakeClient(
+		&v1.IntegrationPlatform{
+			TypeMeta: metav1.TypeMeta{
+				APIVersion: v1.SchemeGroupVersion.String(),
+				Kind:       v1.IntegrationPlatformKind,
+			},
+			ObjectMeta: metav1.ObjectMeta{
+				Namespace: "ns",
+				Name:      "camel-k",
+			},
+		},
 		&v1.IntegrationKit{
 			TypeMeta: metav1.TypeMeta{
 				APIVersion: v1.SchemeGroupVersion.String(),
@@ -82,11 +91,7 @@ func TestLookupKitForIntegration_DiscardKitsInError(t *testing.T) {
 		},
 	)
 
-	assert.Nil(t, err)
-
-	a := buildKitAction{}
-	a.InjectLogger(log.Log)
-	a.InjectClient(c)
+	require.NoError(t, err)
 
 	kits, err := lookupKitsForIntegration(context.TODO(), c, &v1.Integration{
 		TypeMeta: metav1.TypeMeta{
@@ -105,7 +110,7 @@ func TestLookupKitForIntegration_DiscardKitsInError(t *testing.T) {
 		},
 	})
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.NotNil(t, kits)
 	assert.Len(t, kits, 1)
 	assert.Equal(t, "my-kit-2", kits[0].Name)
@@ -113,6 +118,16 @@ func TestLookupKitForIntegration_DiscardKitsInError(t *testing.T) {
 
 func TestLookupKitForIntegration_DiscardKitsWithIncompatibleTraits(t *testing.T) {
 	c, err := test.NewFakeClient(
+		&v1.IntegrationPlatform{
+			TypeMeta: metav1.TypeMeta{
+				APIVersion: v1.SchemeGroupVersion.String(),
+				Kind:       v1.IntegrationPlatformKind,
+			},
+			ObjectMeta: metav1.ObjectMeta{
+				Namespace: "ns",
+				Name:      "camel-k",
+			},
+		},
 		// Should be discarded because it does not contain the required traits
 		&v1.IntegrationKit{
 			TypeMeta: metav1.TypeMeta{
@@ -157,9 +172,7 @@ func TestLookupKitForIntegration_DiscardKitsWithIncompatibleTraits(t *testing.T)
 				},
 				Traits: v1.IntegrationKitTraits{
 					Builder: &traitv1.BuilderTrait{
-						Trait: traitv1.Trait{
-							Enabled: pointer.Bool(false),
-						},
+						PlatformBaseTrait: traitv1.PlatformBaseTrait{},
 					},
 				},
 			},
@@ -188,9 +201,7 @@ func TestLookupKitForIntegration_DiscardKitsWithIncompatibleTraits(t *testing.T)
 				},
 				Traits: v1.IntegrationKitTraits{
 					Builder: &traitv1.BuilderTrait{
-						Trait: traitv1.Trait{
-							Enabled: pointer.Bool(true),
-						},
+						PlatformBaseTrait: traitv1.PlatformBaseTrait{},
 						Properties: []string{
 							"build-key1=build-value1",
 						},
@@ -203,11 +214,7 @@ func TestLookupKitForIntegration_DiscardKitsWithIncompatibleTraits(t *testing.T)
 		},
 	)
 
-	assert.Nil(t, err)
-
-	a := buildKitAction{}
-	a.InjectLogger(log.Log)
-	a.InjectClient(c)
+	require.NoError(t, err)
 
 	kits, err := lookupKitsForIntegration(context.TODO(), c, &v1.Integration{
 		TypeMeta: metav1.TypeMeta{
@@ -221,9 +228,7 @@ func TestLookupKitForIntegration_DiscardKitsWithIncompatibleTraits(t *testing.T)
 		Spec: v1.IntegrationSpec{
 			Traits: v1.Traits{
 				Builder: &traitv1.BuilderTrait{
-					Trait: traitv1.Trait{
-						Enabled: pointer.Bool(true),
-					},
+					PlatformBaseTrait: traitv1.PlatformBaseTrait{},
 					Properties: []string{
 						"build-key1=build-value1",
 					},
@@ -238,7 +243,7 @@ func TestLookupKitForIntegration_DiscardKitsWithIncompatibleTraits(t *testing.T)
 		},
 	})
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.NotNil(t, kits)
 	assert.Len(t, kits, 1)
 	assert.Equal(t, "my-kit-3", kits[0].Name)
@@ -257,9 +262,7 @@ func TestHasMatchingTraits_KitNoTraitShouldNotBePicked(t *testing.T) {
 		Spec: v1.IntegrationSpec{
 			Traits: v1.Traits{
 				Builder: &traitv1.BuilderTrait{
-					Trait: traitv1.Trait{
-						Enabled: pointer.Bool(true),
-					},
+					PlatformBaseTrait: traitv1.PlatformBaseTrait{},
 				},
 			},
 		},
@@ -276,11 +279,8 @@ func TestHasMatchingTraits_KitNoTraitShouldNotBePicked(t *testing.T) {
 		},
 	}
 
-	a := buildKitAction{}
-	a.InjectLogger(log.Log)
-
-	ok, err := trait.IntegrationAndKitHaveSameTraits(integration, kit)
-	assert.Nil(t, err)
+	ok, err := integrationAndKitHaveSameTraits(integration, kit)
+	require.NoError(t, err)
 	assert.False(t, ok)
 }
 
@@ -297,9 +297,7 @@ func TestHasMatchingTraits_KitSameTraitShouldBePicked(t *testing.T) {
 		Spec: v1.IntegrationSpec{
 			Traits: v1.Traits{
 				Builder: &traitv1.BuilderTrait{
-					Trait: traitv1.Trait{
-						Enabled: pointer.Bool(true),
-					},
+					PlatformBaseTrait: traitv1.PlatformBaseTrait{},
 					Properties: []string{
 						"build-key1=build-value1",
 					},
@@ -320,9 +318,7 @@ func TestHasMatchingTraits_KitSameTraitShouldBePicked(t *testing.T) {
 		Spec: v1.IntegrationKitSpec{
 			Traits: v1.IntegrationKitTraits{
 				Builder: &traitv1.BuilderTrait{
-					Trait: traitv1.Trait{
-						Enabled: pointer.Bool(true),
-					},
+					PlatformBaseTrait: traitv1.PlatformBaseTrait{},
 					Properties: []string{
 						"build-key1=build-value1",
 					},
@@ -331,11 +327,8 @@ func TestHasMatchingTraits_KitSameTraitShouldBePicked(t *testing.T) {
 		},
 	}
 
-	a := buildKitAction{}
-	a.InjectLogger(log.Log)
-
-	ok, err := trait.IntegrationAndKitHaveSameTraits(integration, kit)
-	assert.Nil(t, err)
+	ok, err := integrationAndKitHaveSameTraits(integration, kit)
+	require.NoError(t, err)
 	assert.True(t, ok)
 }
 
@@ -356,7 +349,7 @@ func TestHasMatchingSources(t *testing.T) {
 		},
 	}
 
-	hms := hasMatchingSources(integration, kit)
+	hms := hasMatchingSourcesForNative(integration, kit)
 	assert.True(t, hms)
 
 	kit2 := &v1.IntegrationKit{
@@ -368,7 +361,7 @@ func TestHasMatchingSources(t *testing.T) {
 		},
 	}
 
-	hms2 := hasMatchingSources(integration, kit2)
+	hms2 := hasMatchingSourcesForNative(integration, kit2)
 	assert.False(t, hms2)
 }
 
@@ -391,7 +384,7 @@ func TestHasMatchingMultipleSources(t *testing.T) {
 		},
 	}
 
-	hms := hasMatchingSources(integration, kit)
+	hms := hasMatchingSourcesForNative(integration, kit)
 	assert.True(t, hms)
 
 	integration2 := &v1.Integration{
@@ -402,7 +395,7 @@ func TestHasMatchingMultipleSources(t *testing.T) {
 		},
 	}
 
-	hms2 := hasMatchingSources(integration2, kit)
+	hms2 := hasMatchingSourcesForNative(integration2, kit)
 	assert.False(t, hms2)
 }
 
@@ -423,7 +416,7 @@ func TestHasNotMatchingSources(t *testing.T) {
 		},
 	}
 
-	hsm := hasMatchingSources(integration, kit)
+	hsm := hasMatchingSourcesForNative(integration, kit)
 	assert.False(t, hsm)
 
 	kit2 := &v1.IntegrationKit{
@@ -432,6 +425,19 @@ func TestHasNotMatchingSources(t *testing.T) {
 		},
 	}
 
-	hsm2 := hasMatchingSources(integration, kit2)
+	hsm2 := hasMatchingSourcesForNative(integration, kit2)
 	assert.False(t, hsm2)
 }
+
+func integrationAndKitHaveSameTraits(i1 *v1.Integration, i2 *v1.IntegrationKit) (bool, error) {
+	itOpts, err := trait.NewSpecTraitsOptionsForIntegration(i1)
+	if err != nil {
+		return false, err
+	}
+	ikOpts, err := trait.NewSpecTraitsOptionsForIntegrationKit(i2)
+	if err != nil {
+		return false, err
+	}
+
+	return trait.Equals(ikOpts, itOpts), nil
+}
