@@ -70,7 +70,7 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 	}
 
 	// Watch for changes to primary resource IntegrationPlatform
-	err = c.Watch(&source.Kind{Type: &v1.IntegrationPlatform{}},
+	err = c.Watch(source.Kind(mgr.GetCache(), &v1.IntegrationPlatform{}),
 		&handler.EnqueueRequestForObject{},
 		platform.FilteringFuncs{
 			UpdateFunc: func(e event.UpdateEvent) bool {
@@ -155,9 +155,9 @@ func (r *reconcileIntegrationPlatform) Reconcile(ctx context.Context, request re
 
 	actions := []Action{
 		NewInitializeAction(),
-		NewWarmAction(r.reader),
 		NewCreateAction(),
 		NewMonitorAction(),
+		NewCreateCatalogAction(),
 	}
 
 	var targetPhase v1.IntegrationPlatformPhase
