@@ -114,12 +114,17 @@ func KameletCatalog(ctx context.Context, c client.Client, namespace string) erro
 				return err
 			}
 			v := hasServerSideApply.Load()
+			var bundleKamError error
 			if vb, ok := v.(bool); ok && vb {
 				if !once {
-					return serverSideApply(gCtx, c, kamelet)
+					bundleKamError = serverSideApply(gCtx, c, kamelet)
 				}
 			} else {
-				return clientSideApply(gCtx, c, kamelet)
+				bundleKamError = clientSideApply(gCtx, c, kamelet)
+			}
+			// We only log the error. If we returned the error, the creation of the ITP would have stopped
+			if bundleKamError != nil {
+				log.Error(bundleKamError, "Error occurred whilst applying bundled kamelet")
 			}
 			return nil
 		})
@@ -207,8 +212,8 @@ func loadKamelet(path string, namespace string) (ctrl.Object, error) {
 
 // KameletViewerRole installs the role that allows any user ro access kamelets in the global namespace.
 func KameletViewerRole(ctx context.Context, c client.Client, namespace string) error {
-	if err := Resource(ctx, c, namespace, true, IdentityResourceCustomizer, "/viewer/user-global-kamelet-viewer-role.yaml"); err != nil {
+	if err := Resource(ctx, c, namespace, true, IdentityResourceCustomizer, "/resources/viewer/user-global-kamelet-viewer-role.yaml"); err != nil {
 		return err
 	}
-	return Resource(ctx, c, namespace, true, IdentityResourceCustomizer, "/viewer/user-global-kamelet-viewer-role-binding.yaml")
+	return Resource(ctx, c, namespace, true, IdentityResourceCustomizer, "/resources/viewer/user-global-kamelet-viewer-role-binding.yaml")
 }
