@@ -22,12 +22,12 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
-	"github.com/apache/camel-k/v2/pkg/builder"
 	"github.com/apache/camel-k/v2/pkg/util/defaults"
 	"github.com/apache/camel-k/v2/pkg/util/test"
 )
@@ -41,10 +41,10 @@ func TestIntegrationPlatformDefaults(t *testing.T) {
 	}
 
 	c, err := test.NewFakeClient(&ip)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	err = ConfigureDefaults(context.TODO(), c, &ip, false)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	assert.Equal(t, v1.IntegrationPlatformClusterKubernetes, ip.Status.Cluster)
 	assert.Equal(t, v1.TraitProfile(""), ip.Status.Profile)
@@ -52,8 +52,8 @@ func TestIntegrationPlatformDefaults(t *testing.T) {
 	assert.Equal(t, v1.BuildOrderStrategySequential, ip.Status.Build.BuildConfiguration.OrderStrategy)
 	assert.Equal(t, defaults.BaseImage(), ip.Status.Build.BaseImage)
 	assert.Equal(t, defaults.LocalRepository, ip.Status.Build.Maven.LocalRepository)
-	assert.True(t, ip.Status.Build.MaxRunningBuilds == 3) // default for build strategy routine
-	assert.Equal(t, 3, len(ip.Status.Build.Maven.CLIOptions))
+	assert.Equal(t, int32(3), ip.Status.Build.MaxRunningBuilds) // default for build strategy routine
+	assert.Len(t, ip.Status.Build.Maven.CLIOptions, 3)
 	assert.NotNil(t, ip.Status.Traits)
 }
 
@@ -91,10 +91,10 @@ func TestApplyGlobalPlatformSpec(t *testing.T) {
 	}
 
 	c, err := test.NewFakeClient(&global)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	err = ConfigureDefaults(context.TODO(), c, &global, false)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	ip := v1.IntegrationPlatform{
 		ObjectMeta: metav1.ObjectMeta{
@@ -111,7 +111,7 @@ func TestApplyGlobalPlatformSpec(t *testing.T) {
 	assert.Equal(t, v1.TraitProfileOpenShift, ip.Status.Profile)
 	assert.Equal(t, v1.BuildStrategyRoutine, ip.Status.Build.BuildConfiguration.Strategy)
 	assert.Equal(t, v1.BuildOrderStrategyFIFO, ip.Status.Build.BuildConfiguration.OrderStrategy)
-	assert.True(t, ip.Status.Build.MaxRunningBuilds == 3) // default for build strategy routine
+	assert.Equal(t, int32(3), ip.Status.Build.MaxRunningBuilds) // default for build strategy routine
 	assert.Equal(t, len(global.Status.Build.Maven.CLIOptions), len(ip.Status.Build.Maven.CLIOptions))
 	assert.Equal(t, global.Status.Build.Maven.CLIOptions, ip.Status.Build.Maven.CLIOptions)
 	assert.NotNil(t, ip.Status.Traits)
@@ -120,29 +120,28 @@ func TestApplyGlobalPlatformSpec(t *testing.T) {
 	assert.NotNil(t, ip.Status.Traits.Container)
 	assert.Equal(t, corev1.PullAlways, ip.Status.Traits.Container.ImagePullPolicy)
 	assert.Equal(t, "0.1", ip.Status.Traits.Container.LimitCPU)
-	assert.Equal(t, 2, len(ip.Status.Build.Maven.Properties))
+	assert.Len(t, ip.Status.Build.Maven.Properties, 2)
 	assert.Equal(t, "global_value1", ip.Status.Build.Maven.Properties["global_prop1"])
 	assert.Equal(t, "global_value2", ip.Status.Build.Maven.Properties["global_prop2"])
 }
 
-func TestPlatformBuildahUpdateOverrideLocalPlatformSpec(t *testing.T) {
+func TestPlatformS2IhUpdateOverrideLocalPlatformSpec(t *testing.T) {
 	global := v1.IntegrationPlatform{
 		ObjectMeta: metav1.ObjectMeta{
 			Namespace: "ns",
 		},
 		Spec: v1.IntegrationPlatformSpec{
 			Build: v1.IntegrationPlatformBuildSpec{
-				PublishStrategy: v1.IntegrationPlatformBuildPublishStrategyBuildah,
+				PublishStrategy: v1.IntegrationPlatformBuildPublishStrategyS2I,
 			},
 		},
 	}
 
 	c, err := test.NewFakeClient(&global)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	err = ConfigureDefaults(context.TODO(), c, &global, false)
-	assert.Nil(t, err)
-	assert.Equal(t, builder.BuildahDefaultBaseImageName, global.Status.Build.BaseImage)
+	require.NoError(t, err)
 
 	ip := v1.IntegrationPlatform{
 		ObjectMeta: metav1.ObjectMeta{
@@ -151,7 +150,7 @@ func TestPlatformBuildahUpdateOverrideLocalPlatformSpec(t *testing.T) {
 		},
 		Spec: v1.IntegrationPlatformSpec{
 			Build: v1.IntegrationPlatformBuildSpec{
-				PublishStrategy: v1.IntegrationPlatformBuildPublishStrategyBuildah,
+				PublishStrategy: v1.IntegrationPlatformBuildPublishStrategyS2I,
 				BaseImage:       "overridden",
 			},
 		},
@@ -161,29 +160,28 @@ func TestPlatformBuildahUpdateOverrideLocalPlatformSpec(t *testing.T) {
 
 	applyPlatformSpec(&global, &ip)
 
-	assert.Equal(t, v1.IntegrationPlatformBuildPublishStrategyBuildah, ip.Status.Build.PublishStrategy)
+	assert.Equal(t, v1.IntegrationPlatformBuildPublishStrategyS2I, ip.Status.Build.PublishStrategy)
 	assert.Equal(t, "overridden", ip.Status.Build.BaseImage)
 }
 
-func TestPlatformBuildahUpdateDefaultLocalPlatformSpec(t *testing.T) {
-
+func TestPlatformS2IUpdateDefaultLocalPlatformSpec(t *testing.T) {
 	global := v1.IntegrationPlatform{
 		ObjectMeta: metav1.ObjectMeta{
 			Namespace: "ns",
 		},
 		Spec: v1.IntegrationPlatformSpec{
 			Build: v1.IntegrationPlatformBuildSpec{
-				PublishStrategy: v1.IntegrationPlatformBuildPublishStrategyBuildah,
+				PublishStrategy: v1.IntegrationPlatformBuildPublishStrategyS2I,
 				BaseImage:       "overridden",
 			},
 		},
 	}
 
 	c, err := test.NewFakeClient(&global)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	err = ConfigureDefaults(context.TODO(), c, &global, false)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "overridden", global.Status.Build.BaseImage)
 
 	ip := v1.IntegrationPlatform{
@@ -193,7 +191,7 @@ func TestPlatformBuildahUpdateDefaultLocalPlatformSpec(t *testing.T) {
 		},
 		Spec: v1.IntegrationPlatformSpec{
 			Build: v1.IntegrationPlatformBuildSpec{
-				PublishStrategy: v1.IntegrationPlatformBuildPublishStrategyBuildah,
+				PublishStrategy: v1.IntegrationPlatformBuildPublishStrategyS2I,
 			},
 		},
 	}
@@ -202,8 +200,7 @@ func TestPlatformBuildahUpdateDefaultLocalPlatformSpec(t *testing.T) {
 
 	applyPlatformSpec(&global, &ip)
 
-	assert.Equal(t, v1.IntegrationPlatformBuildPublishStrategyBuildah, ip.Status.Build.PublishStrategy)
-	assert.Equal(t, builder.BuildahDefaultBaseImageName, ip.Status.Build.BaseImage)
+	assert.Equal(t, v1.IntegrationPlatformBuildPublishStrategyS2I, ip.Status.Build.PublishStrategy)
 }
 
 func TestRetainLocalPlatformSpec(t *testing.T) {
@@ -240,10 +237,10 @@ func TestRetainLocalPlatformSpec(t *testing.T) {
 	}
 
 	c, err := test.NewFakeClient(&global)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	err = ConfigureDefaults(context.TODO(), c, &global, false)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	ip := v1.IntegrationPlatform{
 		ObjectMeta: metav1.ObjectMeta{
@@ -282,7 +279,7 @@ func TestRetainLocalPlatformSpec(t *testing.T) {
 	assert.Equal(t, v1.TraitProfileKnative, ip.Status.Profile)
 	assert.Equal(t, v1.BuildStrategyPod, ip.Status.Build.BuildConfiguration.Strategy)
 	assert.Equal(t, v1.BuildOrderStrategyFIFO, ip.Status.Build.BuildConfiguration.OrderStrategy)
-	assert.True(t, ip.Status.Build.MaxRunningBuilds == 1)
+	assert.Equal(t, int32(1), ip.Status.Build.MaxRunningBuilds)
 	assert.Equal(t, len(global.Status.Build.Maven.CLIOptions), len(ip.Status.Build.Maven.CLIOptions))
 	assert.Equal(t, global.Status.Build.Maven.CLIOptions, ip.Status.Build.Maven.CLIOptions)
 	assert.NotNil(t, ip.Status.Traits)
@@ -291,7 +288,7 @@ func TestRetainLocalPlatformSpec(t *testing.T) {
 	assert.NotNil(t, ip.Status.Traits.Container)
 	assert.Equal(t, corev1.PullAlways, ip.Status.Traits.Container.ImagePullPolicy)
 	assert.Equal(t, "0.1", ip.Status.Traits.Container.LimitCPU)
-	assert.Equal(t, 3, len(ip.Status.Build.Maven.Properties))
+	assert.Len(t, ip.Status.Build.Maven.Properties, 3)
 	assert.Equal(t, "global_value1", ip.Status.Build.Maven.Properties["global_prop1"])
 	assert.Equal(t, "local_value2", ip.Status.Build.Maven.Properties["global_prop2"])
 	assert.Equal(t, "local_value1", ip.Status.Build.Maven.Properties["local_prop1"])
