@@ -33,47 +33,45 @@ import (
 )
 
 type platformTrait struct {
-	BaseTrait
+	BasePlatformTrait
 	traitv1.PlatformTrait `property:",squash"`
 }
 
 func newPlatformTrait() Trait {
 	return &platformTrait{
-		BaseTrait: NewBaseTrait("platform", 100),
+		BasePlatformTrait: NewBasePlatformTrait("platform", 100),
 	}
 }
 
-func (t *platformTrait) Configure(e *Environment) (bool, error) {
-	if e.Integration == nil || !pointer.BoolDeref(t.Enabled, true) {
-		return false, nil
+func (t *platformTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
+	if e.Integration == nil || e.Integration.IsSynthetic() {
+		// Don't run this trait for a synthetic integration
+		return false, nil, nil
 	}
 
 	if !e.IntegrationInPhase(v1.IntegrationPhaseNone, v1.IntegrationPhaseWaitingForPlatform) {
-		return false, nil
+		return false, nil, nil
 	}
 
-	if !pointer.BoolDeref(t.Auto, false) {
-		if e.Platform == nil {
-			if t.CreateDefault == nil {
-				// Calculate if the platform should be automatically created when missing.
-				if ocp, err := openshift.IsOpenShift(t.Client); err != nil {
-					return false, err
-				} else if ocp {
-					t.CreateDefault = &ocp
-				} else if addr, err := image.GetRegistryAddress(e.Ctx, t.Client); err != nil {
-					return false, err
-				} else if addr != nil {
-					t.CreateDefault = pointer.Bool(true)
-				}
-			}
-			if t.Global == nil {
-				globalOperator := platform.IsCurrentOperatorGlobal()
-				t.Global = &globalOperator
-			}
+	if t.CreateDefault == nil && pointer.BoolDeref(t.Auto, false) && e.Platform == nil {
+		// Calculate if the platform should be automatically created when missing.
+		if ocp, err := openshift.IsOpenShift(t.Client); err != nil {
+			return false, nil, err
+		} else if ocp {
+			t.CreateDefault = pointer.Bool(true)
+		} else if addr, err := image.GetRegistryAddress(e.Ctx, t.Client); err != nil {
+			return false, nil, err
+		} else if addr != nil {
+			t.CreateDefault = pointer.Bool(true)
 		}
 	}
 
-	return true, nil
+	if t.Global == nil {
+		globalOperator := platform.IsCurrentOperatorGlobal()
+		t.Global = &globalOperator
+	}
+
+	return true, nil, nil
 }
 
 func (t *platformTrait) Apply(e *Environment) error {
@@ -111,7 +109,7 @@ func (t *platformTrait) Apply(e *Environment) error {
 }
 
 func (t *platformTrait) getOrCreatePlatform(e *Environment) (*v1.IntegrationPlatform, error) {
-	pl, err := platform.GetOrFindForResource(e.Ctx, t.Client, e.Integration, false)
+	pl, err := platform.GetForResource(e.Ctx, t.Client, e.Integration)
 	if err != nil && apierrors.IsNotFound(err) && pointer.BoolDeref(t.CreateDefault, false) {
 		platformName := e.Integration.Status.Platform
 		if platformName == "" {
@@ -152,11 +150,6 @@ func (t *platformTrait) getOrCreatePlatform(e *Environment) (*v1.IntegrationPlat
 	return pl, err
 }
 
-// IsPlatformTrait overrides base class method.
-func (t *platformTrait) IsPlatformTrait() bool {
-	return true
-}
-
 // RequiresIntegrationPlatform overrides base class method.
 func (t *platformTrait) RequiresIntegrationPlatform() bool {
 	return false
