@@ -21,6 +21,7 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 
 	"k8s.io/apimachinery/pkg/util/yaml"
 
@@ -36,15 +37,17 @@ import (
 
 func TestConfigurePodTraitDoesSucceed(t *testing.T) {
 	trait, environment, _ := createPodTest("")
-	configured, err := trait.Configure(environment)
+	configured, condition, err := trait.Configure(environment)
 
 	assert.True(t, configured)
-	assert.Nil(t, err)
+	assert.Nil(t, condition)
+	require.NoError(t, err)
 
-	configured, err = trait.Configure(environment)
+	configured, condition, err = trait.Configure(environment)
 
 	assert.True(t, configured)
-	assert.Nil(t, err)
+	assert.Nil(t, condition)
+	require.NoError(t, err)
 }
 
 func TestSimpleChange(t *testing.T) {
@@ -203,11 +206,12 @@ func testPodTemplateSpec(t *testing.T, template string) corev1.PodTemplateSpec {
 
 	trait, environment, _ := createPodTest(template)
 
-	_, err := trait.Configure(environment)
-	assert.Nil(t, err)
+	_, condition, err := trait.Configure(environment)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
 
 	err = trait.Apply(environment)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	deployment := environment.Resources.GetDeployment(func(deployment *appsv1.Deployment) bool {
 		return deployment.Name == "pod-template-test-integration"
