@@ -33,6 +33,7 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/client"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestPullSecret(t *testing.T) {
@@ -40,12 +41,13 @@ func TestPullSecret(t *testing.T) {
 
 	trait, _ := newPullSecretTrait().(*pullSecretTrait)
 	trait.SecretName = "xxxy"
-	enabled, err := trait.Configure(e)
-	assert.Nil(t, err)
+	enabled, condition, err := trait.Configure(e)
+	require.NoError(t, err)
 	assert.True(t, enabled)
+	assert.Nil(t, condition)
 
 	err = trait.Apply(e)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Contains(t, deployment.Spec.Template.Spec.ImagePullSecrets, corev1.LocalObjectReference{Name: "xxxy"})
 }
 
@@ -54,9 +56,10 @@ func TestPullSecretDoesNothingWhenNotSetOnPlatform(t *testing.T) {
 	e.Platform = &v1.IntegrationPlatform{}
 
 	trait := newPullSecretTrait()
-	enabled, err := trait.Configure(e)
-	assert.Nil(t, err)
+	enabled, condition, err := trait.Configure(e)
+	require.NoError(t, err)
 	assert.False(t, enabled)
+	assert.Nil(t, condition)
 }
 
 func TestPullSecretAuto(t *testing.T) {
@@ -64,9 +67,10 @@ func TestPullSecretAuto(t *testing.T) {
 
 	trait, _ := newPullSecretTrait().(*pullSecretTrait)
 	trait.Auto = pointer.Bool(false)
-	enabled, err := trait.Configure(e)
-	assert.Nil(t, err)
+	enabled, condition, err := trait.Configure(e)
+	require.NoError(t, err)
 	assert.False(t, enabled)
+	assert.Nil(t, condition)
 }
 
 func TestPullSecretImagePullerDelegation(t *testing.T) {
@@ -75,13 +79,14 @@ func TestPullSecretImagePullerDelegation(t *testing.T) {
 	trait, _ := newPullSecretTrait().(*pullSecretTrait)
 	trait.Auto = pointer.Bool(false)
 	trait.ImagePullerDelegation = pointer.Bool(true)
-	enabled, err := trait.Configure(e)
-	assert.Nil(t, err)
+	enabled, condition, err := trait.Configure(e)
+	require.NoError(t, err)
 	assert.True(t, enabled)
+	assert.Nil(t, condition)
 	assert.True(t, *trait.ImagePullerDelegation)
 
 	err = trait.Apply(e)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
 	var roleBinding rbacv1.RoleBinding
 	roleBindingKey := client.ObjectKey{
@@ -89,7 +94,7 @@ func TestPullSecretImagePullerDelegation(t *testing.T) {
 		Name:      "camel-k-puller-test-default",
 	}
 	err = e.Client.Get(e.Ctx, roleBindingKey, &roleBinding)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Len(t, roleBinding.Subjects, 1)
 }
 
@@ -123,7 +128,7 @@ func getEnvironmentAndDeployment(t *testing.T) (*Environment, *appsv1.Deployment
 	var err error
 	e.Ctx = context.TODO()
 	e.Client, err = test.NewFakeClient(e.Integration, &deployment)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
 	return e, &deployment
 }
