@@ -20,53 +20,50 @@ package trait
 import (
 	"testing"
 
-	"github.com/stretchr/testify/assert"
+	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 
-	"k8s.io/utils/pointer"
+	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/v2/pkg/builder"
 	"github.com/apache/camel-k/v2/pkg/util/camel"
+	"github.com/apache/camel-k/v2/pkg/util/test"
 )
 
 func TestConfigureQuarkusTraitBuildSubmitted(t *testing.T) {
 	quarkusTrait, environment := createNominalQuarkusTest()
 	environment.IntegrationKit.Status.Phase = v1.IntegrationKitPhaseBuildSubmitted
 
-	configured, err := quarkusTrait.Configure(environment)
+	configured, condition, err := quarkusTrait.Configure(environment)
 
 	assert.True(t, configured)
-	assert.Nil(t, err)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
 
 	err = quarkusTrait.Apply(environment)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	build := getBuilderTask(environment.Pipeline)
 	assert.NotNil(t, t, build)
+	assert.Len(t, build.Steps, len(builder.Quarkus.CommonSteps))
 
-	assert.Len(t, build.Steps, len(builder.Quarkus.CommonSteps)+3)
-}
-
-func TestConfigureDisabledQuarkusTraitShouldFail(t *testing.T) {
-	quarkusTrait, environment := createNominalQuarkusTest()
-	quarkusTrait.Enabled = pointer.Bool(false)
-
-	configured, err := quarkusTrait.Configure(environment)
-
-	assert.False(t, configured)
-	assert.Nil(t, err)
+	packageTask := getPackageTask(environment.Pipeline)
+	assert.NotNil(t, t, packageTask)
+	assert.Len(t, packageTask.Steps, 4)
 }
 
 func TestApplyQuarkusTraitDefaultKitLayout(t *testing.T) {
 	quarkusTrait, environment := createNominalQuarkusTest()
 	environment.Integration.Status.Phase = v1.IntegrationPhaseBuildingKit
 
-	configured, err := quarkusTrait.Configure(environment)
+	configured, condition, err := quarkusTrait.Configure(environment)
 	assert.True(t, configured)
-	assert.Nil(t, err)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
 
 	err = quarkusTrait.Apply(environment)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Len(t, environment.IntegrationKits, 1)
 	assert.Equal(t, environment.IntegrationKits[0].Labels[v1.IntegrationKitLayoutLabel], v1.IntegrationKitLayoutFastJar)
 }
@@ -77,23 +74,43 @@ func TestApplyQuarkusTraitAnnotationKitConfiguration(t *testing.T) {
 
 	v1.SetAnnotation(&environment.Integration.ObjectMeta, v1.TraitAnnotationPrefix+"quarkus.foo", "camel-k")
 
-	configured, err := quarkusTrait.Configure(environment)
+	configured, condition, err := quarkusTrait.Configure(environment)
 	assert.True(t, configured)
-	assert.Nil(t, err)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
 
 	err = quarkusTrait.Apply(environment)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Len(t, environment.IntegrationKits, 1)
 	assert.Equal(t, v1.IntegrationKitLayoutFastJar, environment.IntegrationKits[0].Labels[v1.IntegrationKitLayoutLabel])
 	assert.Equal(t, "camel-k", environment.IntegrationKits[0].Annotations[v1.TraitAnnotationPrefix+"quarkus.foo"])
 
 }
 
+func TestQuarkusTraitBuildModeOrder(t *testing.T) {
+	quarkusTrait, environment := createNominalQuarkusTest()
+	quarkusTrait.Modes = []traitv1.QuarkusMode{traitv1.NativeQuarkusMode, traitv1.JvmQuarkusMode}
+	environment.Integration.Status.Phase = v1.IntegrationPhaseBuildingKit
+	environment.Integration.Spec.Sources = []v1.SourceSpec{
+		{
+			Language: v1.LanguageYaml,
+		},
+	}
+
+	err := quarkusTrait.Apply(environment)
+	require.NoError(t, err)
+	assert.Len(t, environment.IntegrationKits, 2)
+	// assure jvm mode is executed before native mode
+	assert.Equal(t, environment.IntegrationKits[0].Labels[v1.IntegrationKitLayoutLabel], v1.IntegrationKitLayoutFastJar)
+	assert.Equal(t, environment.IntegrationKits[1].Labels[v1.IntegrationKitLayoutLabel], v1.IntegrationKitLayoutNativeSources)
+}
+
 func createNominalQuarkusTest() (*quarkusTrait, *Environment) {
 	trait, _ := newQuarkusTrait().(*quarkusTrait)
-	trait.Enabled = pointer.Bool(true)
+	client, _ := test.NewFakeClient()
 
 	environment := &Environment{
+		Catalog:      NewCatalog(client),
 		CamelCatalog: &camel.RuntimeCatalog{},
 		Integration: &v1.Integration{
 			Spec: v1.IntegrationSpec{
@@ -109,6 +126,9 @@ func createNominalQuarkusTest() (*quarkusTrait, *Environment) {
 			{
 				Builder: &v1.BuilderTask{},
 			},
+			{
+				Package: &v1.BuilderTask{},
+			},
 		},
 		Platform: &v1.IntegrationPlatform{},
 	}
@@ -205,3 +225,31 @@ func TestGetLanguageSettingsWithLoaders(t *testing.T) {
 	assert.Equal(t, languageSettings{native: false, sourcesRequiredAtBuildTime: true}, getLanguageSettings(environment, v1.LanguageKotlin))
 	assert.Equal(t, languageSettings{native: true, sourcesRequiredAtBuildTime: false}, getLanguageSettings(environment, v1.LanguageJavaShell))
 }
+
+func TestQuarkusMatches(t *testing.T) {
+	qt := quarkusTrait{
+		BasePlatformTrait: NewBasePlatformTrait("quarkus", 600),
+		QuarkusTrait: traitv1.QuarkusTrait{
+			Modes: []traitv1.QuarkusMode{traitv1.JvmQuarkusMode},
+		},
+	}
+	qt2 := quarkusTrait{
+		BasePlatformTrait: NewBasePlatformTrait("quarkus", 600),
+		QuarkusTrait: traitv1.QuarkusTrait{
+			Modes:           []traitv1.QuarkusMode{traitv1.JvmQuarkusMode},
+			NativeBaseImage: QuarkusNativeDefaultBaseImageName,
+		},
+	}
+
+	assert.True(t, qt.Matches(&qt2))
+	qt2.Modes = append(qt2.Modes, traitv1.NativeQuarkusMode)
+	assert.True(t, qt.Matches(&qt2))
+	qt2.Modes = []traitv1.QuarkusMode{traitv1.NativeQuarkusMode}
+	assert.False(t, qt.Matches(&qt2))
+	qt2.Modes = nil
+	assert.True(t, qt.Matches(&qt2))
+	qt2.Modes = []traitv1.QuarkusMode{}
+	assert.True(t, qt.Matches(&qt2))
+	qt2.NativeBaseImage = "docker.io/my-new-native-base"
+	assert.False(t, qt.Matches(&qt2))
+}
