@@ -29,6 +29,7 @@ import (
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 	"github.com/apache/camel-k/v2/pkg/platform"
+	"github.com/apache/camel-k/v2/pkg/util/defaults"
 	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
 	"github.com/apache/camel-k/v2/pkg/util/registry"
 
@@ -53,24 +54,29 @@ func (t *registryTrait) InfluencesKit() bool {
 	return true
 }
 
-// InfluencesBuild overrides base class method.
-func (t *registryTrait) InfluencesBuild(this, prev map[string]interface{}) bool {
-	return true
-}
-
-func (t *registryTrait) Configure(e *Environment) (bool, error) {
+func (t *registryTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
 	// disabled by default
 	if e.IntegrationKit == nil || !pointer.BoolDeref(t.Enabled, false) {
-		return false, nil
+		return false, nil, nil
 	}
-
-	return e.IntegrationKitInPhase(v1.IntegrationKitPhaseBuildSubmitted), nil
+	enabled := e.IntegrationKitInPhase(v1.IntegrationKitPhaseBuildSubmitted)
+	if enabled {
+		condition := NewIntegrationCondition(
+			"Registry",
+			v1.IntegrationConditionTraitInfo,
+			corev1.ConditionTrue,
+			traitConfigurationReason,
+			"Registry trait is deprecated. It may be removed in future version. Read documentation to find alternatives (likely JVM trait).",
+		)
+		return true, condition, nil
+	}
+	return false, nil, nil
 }
 
 func (t *registryTrait) Apply(e *Environment) error {
 	registryAddress := e.Platform.Status.Build.Registry.Address
 	if registryAddress == "" && e.Platform.Status.Cluster == v1.IntegrationPlatformClusterOpenShift {
-		registryAddress = "image-registry.openshift-image-registry.svc:5000"
+		registryAddress = defaults.OpenShiftRegistryAddress
 	}
 	if registryAddress == "" {
 		return errors.New("could not figure out Image Registry URL, please set it manually")
