@@ -52,7 +52,7 @@ func TestTraitConfiguration(t *testing.T) {
 		},
 	}
 	c := NewCatalog(nil)
-	assert.NoError(t, c.Configure(&env))
+	require.NoError(t, c.Configure(&env))
 	logging, ok := c.GetTrait("logging").(*loggingTrait)
 	require.True(t, ok)
 	assert.True(t, *logging.JSON)
@@ -85,7 +85,7 @@ func TestTraitConfigurationFromAnnotations(t *testing.T) {
 		},
 	}
 	c := NewCatalog(nil)
-	assert.NoError(t, c.Configure(&env))
+	require.NoError(t, c.Configure(&env))
 	ct, _ := c.GetTrait("cron").(*cronTrait)
 	assert.True(t, *ct.Fallback)
 	assert.Equal(t, "annotated-policy", ct.ConcurrencyPolicy)
@@ -163,7 +163,7 @@ func TestTraitConfigurationOverrideRulesFromAnnotations(t *testing.T) {
 		},
 	}
 	c := NewCatalog(nil)
-	assert.NoError(t, c.Configure(&env))
+	require.NoError(t, c.Configure(&env))
 	ct, _ := c.GetTrait("cron").(*cronTrait)
 	assert.Equal(t, "schedule2", ct.Schedule)
 	assert.Equal(t, "cmp4", ct.Components)
@@ -187,7 +187,7 @@ func TestTraitListConfigurationFromAnnotations(t *testing.T) {
 		},
 	}
 	c := NewCatalog(nil)
-	assert.NoError(t, c.Configure(&env))
+	require.NoError(t, c.Configure(&env))
 	jt, _ := c.GetTrait("jolokia").(*jolokiaTrait)
 	assert.Equal(t, []string{"opt1", "opt2"}, jt.Options)
 	sbt, _ := c.GetTrait("service-binding").(*serviceBindingTrait)
@@ -208,22 +208,17 @@ func TestTraitSplitConfiguration(t *testing.T) {
 		},
 	}
 	c := NewCatalog(nil)
-	assert.NoError(t, c.Configure(&env))
+	require.NoError(t, c.Configure(&env))
 	ot, _ := c.GetTrait("owner").(*ownerTrait)
 	assert.Equal(t, []string{"opt1", "opt2"}, ot.TargetLabels)
 }
 
 func TestTraitDecode(t *testing.T) {
 	trait := traitToMap(t, traitv1.ContainerTrait{
-		Trait: traitv1.Trait{
-			Enabled: pointer.Bool(false),
-			Configuration: configurationFromMap(t, map[string]interface{}{
-				"name": "test-container",
-				"port": 8081,
-			}),
-		},
-		Port: 7071,
-		Auto: pointer.Bool(false),
+		PlatformBaseTrait: traitv1.PlatformBaseTrait{},
+		Name:              "test-container",
+		Port:              7071,
+		Auto:              pointer.Bool(false),
 	})
 
 	target, ok := newContainerTrait().(*containerTrait)
@@ -231,9 +226,7 @@ func TestTraitDecode(t *testing.T) {
 	err := decodeTrait(trait, target)
 	require.NoError(t, err)
 
-	assert.Equal(t, false, pointer.BoolDeref(target.Enabled, true))
 	assert.Equal(t, "test-container", target.Name)
-	// legacy configuration should not override a value in new API field
 	assert.Equal(t, 7071, target.Port)
-	assert.Equal(t, false, pointer.BoolDeref(target.Auto, true))
+	assert.False(t, pointer.BoolDeref(target.Auto, true))
 }
