@@ -24,7 +24,7 @@ import (
 	"testing"
 
 	"github.com/apache/camel-k/v2/pkg/util"
-	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestRunAndLogErrorMvn(t *testing.T) {
@@ -34,8 +34,8 @@ func TestRunAndLogErrorMvn(t *testing.T) {
 	}
 
 	cmd := exec.CommandContext(context.Background(), mavenCmd, "package", "-B")
-	err := util.RunAndLog(context.Background(), cmd, mavenLogHandler, mavenLogHandler)
+	err := util.RunAndLog(context.Background(), cmd, MavenLogHandler, MavenLogHandler)
 
-	assert.NotNil(t, err)
-	assert.ErrorContains(t, err, "[ERROR] The goal you specified requires a project to execute but there is no POM in this directory")
+	require.Error(t, err)
+	require.ErrorContains(t, err, "[ERROR] The goal you specified requires a project to execute but there is no POM in this directory")
 }
